searchNodes=[{"ref":"NetAddr.html","title":"NetAddr","type":"module","doc":"General functions for network address parsing and manipulation, with support for addresses of arbitrary size."},{"ref":"NetAddr.html#address/1","title":"NetAddr.address/1","type":"function","doc":"Returns a human-readable string for the address part of netaddr. Examples iex&gt; NetAddr.address NetAddr.ip(&quot;192.0.2.1/24&quot;) &quot;192.0.2.1&quot; iex&gt; NetAddr.address NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;) &quot;0x0102030405&quot;"},{"ref":"NetAddr.html#address_length/1","title":"NetAddr.address_length/1","type":"function","doc":"Return the address length of netaddr. Examples iex&gt; NetAddr.address_length NetAddr.ip(&quot;192.0.2.1/24&quot;) 24"},{"ref":"NetAddr.html#address_length/2","title":"NetAddr.address_length/2","type":"function","doc":"Returns a new NetAddr.t/0 with the address part of netaddr and the given address length. Examples iex&gt; NetAddr.ip(&quot;192.0.2.1/24&quot;) ...&gt; |&gt; NetAddr.address_length(22) %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 22}"},{"ref":"NetAddr.html#address_size/1","title":"NetAddr.address_size/1","type":"function","doc":"Returns size of netaddr in bytes. Examples iex&gt; NetAddr.address_size NetAddr.ip(&quot;192.0.2.1&quot;) 4 iex&gt; NetAddr.address_size NetAddr.ip(&quot;::&quot;) 16 iex&gt; NetAddr.address_size NetAddr.mac_48(&quot;c0:ff:33:c0:ff:33&quot;) 6 iex&gt; NetAddr.address_size NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;) 5"},{"ref":"NetAddr.html#apply_mask/2","title":"NetAddr.apply_mask/2","type":"function","doc":"Bitwise ANDs two address binaries, returning the result. Examples iex&gt; NetAddr.apply_mask &lt;&lt;192,0,2,1&gt;&gt;, &lt;&lt;255,255,255,0&gt;&gt; &lt;&lt;192, 0, 2, 0&gt;&gt; iex&gt; NetAddr.apply_mask &lt;&lt;192,0,2,1&gt;&gt;, &lt;&lt;14,249,150,22&gt;&gt; &lt;&lt;0,0,2,0&gt;&gt;"},{"ref":"NetAddr.html#aton/1","title":"NetAddr.aton/1","type":"function","doc":"Converts address to a decimal. Examples iex&gt; NetAddr.aton &lt;&lt;192,0,2,1&gt;&gt; 3221225985 iex&gt; NetAddr.aton &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt; 338288524986991696549538495105230488577 iex&gt; NetAddr.aton(&lt;&lt;1,2,3,4,5&gt;&gt;) 4328719365"},{"ref":"NetAddr.html#broadcast/1","title":"NetAddr.broadcast/1","type":"function","doc":"Returns a human-readable string for the last address in ipv4_netaddr. Examples iex&gt; NetAddr.broadcast NetAddr.ip(&quot;192.0.2.1/24&quot;) &quot;192.0.2.255&quot;"},{"ref":"NetAddr.html#contains?/2","title":"NetAddr.contains?/2","type":"function","doc":"Tests whether netaddr contains netaddr2, up to equality. Examples iex&gt; NetAddr.ip(&quot;192.0.2.0/24&quot;) ...&gt; |&gt; NetAddr.contains?(NetAddr.ip(&quot;192.0.2.0/25&quot;)) true iex&gt; NetAddr.ip(&quot;192.0.2.0/24&quot;) ...&gt; |&gt; NetAddr.contains?(NetAddr.ip(&quot;192.0.2.0/24&quot;)) true iex&gt; NetAddr.ip(&quot;192.0.2.0/25&quot;) ...&gt; |&gt; NetAddr.contains?(NetAddr.ip(&quot;192.0.2.0/24&quot;)) false iex&gt; NetAddr.ip(&quot;192.0.2.0/25&quot;) ...&gt; |&gt; NetAddr.contains?(NetAddr.ip(&quot;192.0.2.128/25&quot;)) false iex&gt; NetAddr.ip(&quot;192.0.2.3/31&quot;) ...&gt; |&gt; NetAddr.contains?(NetAddr.ip(&quot;192.0.2.2&quot;)) true"},{"ref":"NetAddr.html#embed/2","title":"NetAddr.embed/2","type":"function","doc":""},{"ref":"NetAddr.html#erl_ip_to_netaddr/1","title":"NetAddr.erl_ip_to_netaddr/1","type":"function","doc":"Constructs a NetAddr.t/0 struct given an Erlang/OTP IP address tuple. Examples iex&gt; NetAddr.erl_ip_to_netaddr({192, 0, 2, 1}) {:ok, %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 32}} iex&gt; NetAddr.erl_ip_to_netaddr({0x2001, 0xdb8, 0, 0, 0, 0, 0, 1}) {:ok, %NetAddr.IPv6{address: &lt;&lt;0x2001::16, 0xdb8::16, 0::5*16, 1::16&gt;&gt;, length: 128}}"},{"ref":"NetAddr.html#first_address/1","title":"NetAddr.first_address/1","type":"function","doc":"Returns a new NetAddr.t/0 with the first address in netaddr. Examples iex&gt; NetAddr.first_address NetAddr.ip(&quot;192.0.2.1/24&quot;) %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 0&gt;&gt;, length: 24}"},{"ref":"NetAddr.html#ip/1","title":"NetAddr.ip/1","type":"function","doc":"Parses ip_string as an IPv4/IPv6 address or CIDR, returning a NetAddr.IPv4.t/0 or NetAddr.IPv6.t/0 as appropriate. Examples iex&gt; NetAddr.ip &quot;192.0.2.1&quot; %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 32} iex&gt; NetAddr.ip &quot;192.0.2.1/24&quot; %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 24} iex&gt; NetAddr.ip &quot;fe80::c101&quot; %NetAddr.IPv6{address: &lt;&lt;0xfe,0x80,0::12*8,0xc1,0x01&gt;&gt;, length: 128} iex&gt; NetAddr.ip &quot;fe80::c101/64&quot; %NetAddr.IPv6{address: &lt;&lt;0xfe,0x80,0::12*8,0xc1,0x01&gt;&gt;, length: 64} iex&gt; NetAddr.ip &quot;blarg&quot; {:error, :einval}"},{"ref":"NetAddr.html#ip/2","title":"NetAddr.ip/2","type":"function","doc":"Parses ip_address_string with the given address length or ip_mask_string. Examples iex&gt; NetAddr.ip &quot;0.0.0.0&quot;, 0 %NetAddr.IPv4{address: &lt;&lt;0, 0, 0, 0&gt;&gt;, length: 0} iex&gt; NetAddr.ip &quot;192.0.2.1&quot;, 24 %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 24} iex&gt; NetAddr.ip &quot;192.0.2.1&quot;, &quot;255.255.255.0&quot; %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 24} iex&gt; NetAddr.ip &quot;fe80:0:c100::c401&quot;, 64 %NetAddr.IPv6{address: &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt;, length: 64} iex&gt; NetAddr.ip &quot;blarg&quot;, 32 {:error, :einval} iex&gt; NetAddr.ip &quot;192.0.2.010&quot; %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 10&gt;&gt;, length: 32} iex&gt; NetAddr.ip &quot;192.0.2.1/33&quot; {:error, :einval}"},{"ref":"NetAddr.html#ip_2/1","title":"NetAddr.ip_2/1","type":"function","doc":"Identical to ip/1, but returns {:ok, value} on success instead of just value. Examples iex&gt; NetAddr.ip_2 &quot;192.0.2.1&quot; {:ok, %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 32}} iex&gt; NetAddr.ip_2 &quot;192.0.2.1/24&quot; {:ok, %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 24}} iex&gt; NetAddr.ip_2 &quot;fe80::c101&quot; {:ok, %NetAddr.IPv6{address: &lt;&lt;0xfe,0x80,0::12*8,0xc1,0x01&gt;&gt;, length: 128}} iex&gt; NetAddr.ip_2 &quot;fe80::c101/64&quot; {:ok, %NetAddr.IPv6{address: &lt;&lt;0xfe,0x80,0::12*8,0xc1,0x01&gt;&gt;, length: 64}} iex&gt; NetAddr.ip_2 &quot;blarg&quot; {:error, :einval}"},{"ref":"NetAddr.html#ip_2/2","title":"NetAddr.ip_2/2","type":"function","doc":"Identical to ip/2, but returns {:ok, value} on success instead of just value. Examples iex&gt; NetAddr.ip_2 &quot;0.0.0.0&quot;, 0 {:ok, %NetAddr.IPv4{address: &lt;&lt;0, 0, 0, 0&gt;&gt;, length: 0}} iex&gt; NetAddr.ip_2 &quot;192.0.2.1&quot;, 24 {:ok, %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 24}} iex&gt; NetAddr.ip_2 &quot;192.0.2.1&quot;, &quot;255.255.255.0&quot; {:ok, %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 24}} iex&gt; NetAddr.ip_2 &quot;192.0.2.1&quot;, &quot;14.249.150.22&quot; {:error, :einval} iex&gt; NetAddr.ip_2 &quot;fe80:0:c100::c401&quot;, 64 {:ok, %NetAddr.IPv6{address: &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt;, length: 64}} iex&gt; NetAddr.ip_2 &quot;blarg&quot;, 32 {:error, :einval}"},{"ref":"NetAddr.html#is_host_address/1","title":"NetAddr.is_host_address/1","type":"function","doc":"Tests whether netaddr has length equal to its size in bits. Examples iex&gt; NetAddr.is_host_address NetAddr.ip(&quot;0.0.0.0/0&quot;) false iex&gt; NetAddr.is_host_address NetAddr.ip(&quot;192.0.2.1&quot;) true iex&gt; NetAddr.is_host_address NetAddr.ip(&quot;fe80:0:c100::c401&quot;) true iex&gt; NetAddr.is_host_address NetAddr.ip(&quot;::/0&quot;) false"},{"ref":"NetAddr.html#is_ip/1","title":"NetAddr.is_ip/1","type":"function","doc":"Tests whether string can be parsed as an IP address. Examples iex&gt; NetAddr.is_ip &quot;not an IP address&quot; false iex&gt; NetAddr.is_ip %{} false iex&gt; NetAddr.is_ip &quot;0.0.0.0/0&quot; true iex&gt; NetAddr.is_ip &quot;192.0.2.1&quot; true iex&gt; NetAddr.is_ip &quot;fe80:0:c100::c401&quot; true iex&gt; NetAddr.is_ip &quot;::/0&quot; true"},{"ref":"NetAddr.html#is_ipv4/1","title":"NetAddr.is_ipv4/1","type":"function","doc":"Tests whether string can be parsed as an IPv4 address. Examples iex&gt; NetAddr.is_ipv4 &quot;not an IP address&quot; false iex&gt; NetAddr.is_ip %{} false iex&gt; NetAddr.is_ipv4 &quot;0.0.0.0/0&quot; true iex&gt; NetAddr.is_ipv4 &quot;192.0.2.1&quot; true iex&gt; NetAddr.is_ipv4 &quot;fe80:0:c100::c401&quot; false iex&gt; NetAddr.is_ipv4 &quot;::/0&quot; false"},{"ref":"NetAddr.html#is_ipv6/1","title":"NetAddr.is_ipv6/1","type":"function","doc":"Tests whether string can be parsed as an IPv6 address. Examples iex&gt; NetAddr.is_ipv6 &quot;not an IP address&quot; false iex&gt; NetAddr.is_ip %{} false iex&gt; NetAddr.is_ipv6 &quot;0.0.0.0/0&quot; false iex&gt; NetAddr.is_ipv6 &quot;192.0.2.1&quot; false iex&gt; NetAddr.is_ipv6 &quot;fe80:0:c100::c401&quot; true iex&gt; NetAddr.is_ipv6 &quot;::/0&quot; true"},{"ref":"NetAddr.html#last_address/1","title":"NetAddr.last_address/1","type":"function","doc":"Returns a new NetAddr.t/0 with the last address in netaddr. Examples iex&gt; NetAddr.last_address NetAddr.ip(&quot;192.0.2.1/24&quot;) %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 255&gt;&gt;, length: 24}"},{"ref":"NetAddr.html#length_to_mask/2","title":"NetAddr.length_to_mask/2","type":"function","doc":"Converts address_length to an address mask binary. Examples iex&gt; NetAddr.length_to_mask(30, 4) &lt;&lt;255, 255, 255, 252&gt;&gt; iex&gt; NetAddr.length_to_mask(64, 16) &lt;&lt;255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0&gt;&gt; iex&gt; NetAddr.length_to_mask(37, 6) &lt;&lt;255, 255, 255, 255, 248, 0&gt;&gt;"},{"ref":"NetAddr.html#mac_48/1","title":"NetAddr.mac_48/1","type":"function","doc":"Parses mac_string, returning a NetAddr.MAC_48.t/0. For manifest reasons, the corresponding parser may be robust to the point of returning incorrect results. Caveat emptor. Examples iex&gt; NetAddr.mac_48 &quot;01:23:45:67:89:AB&quot; %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;01-23-45-67-89-AB&quot; %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;0123456789aB&quot; %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;01 23 45 67 89 AB&quot; %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;\\&quot;0fF:33-C0.Ff 33 \\&quot;&quot; %NetAddr.MAC_48{address: &lt;&lt;0x0f, 0xf, 0x33, 0xc0, 0xff, 0x33&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;1:2:3:4:5:6&quot; %NetAddr.MAC_48{address: &lt;&lt;1,2,3,4,5,6&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;01-23-45-67-89-ag&quot; %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xa&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;123456789aB&quot; %NetAddr.MAC_48{address: &lt;&lt;0x12,0x34,0x56,0x78,0x9a,0xb&gt;&gt;, length: 48} iex&gt; NetAddr.mac_48 &quot;blarg&quot; {:error, :einval}"},{"ref":"NetAddr.html#mac_48_2/1","title":"NetAddr.mac_48_2/1","type":"function","doc":"Identical to mac_48/1, but returns {:ok, value} on success instead of just value. Examples iex&gt; NetAddr.mac_48_2 &quot;01:23:45:67:89:AB&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;01-23-45-67-89-AB&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;0123456789aB&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;01 23 45 67 89 AB&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xab&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;\\&quot;0fF:33-C0.Ff 33 \\&quot;&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;0x0f, 0xf, 0x33, 0xc0, 0xff, 0x33&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;1:2:3:4:5:6&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;1,2,3,4,5,6&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;01-23-45-67-89-ag&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;0x01,0x23,0x45,0x67,0x89,0xa&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;123456789aB&quot; {:ok, %NetAddr.MAC_48{address: &lt;&lt;0x12,0x34,0x56,0x78,0x9a,0xb&gt;&gt;, length: 48}} iex&gt; NetAddr.mac_48_2 &quot;blarg&quot; {:error, :einval}"},{"ref":"NetAddr.html#mask_to_length/1","title":"NetAddr.mask_to_length/1","type":"function","doc":"Converts address_mask to an address length. Examples iex&gt; NetAddr.mask_to_length(&lt;&lt;255,255,248,0&gt;&gt;) 21"},{"ref":"NetAddr.html#mask_to_length_2/1","title":"NetAddr.mask_to_length_2/1","type":"function","doc":"Convert address_mask to an address length. Unlike mask_to_length/1, this function returns {:ok, length}, on success, and {:error, :einval}, otherwise. In particular, this function rejects a mask that contains non-consecutive ones bits. Examples iex&gt; NetAddr.mask_to_length_2(&lt;&lt;255,255,248,0&gt;&gt;) {:ok, 21} iex&gt; NetAddr.mask_to_length_2(&lt;&lt;14,249,150,22&gt;&gt;) {:error, :einval}"},{"ref":"NetAddr.html#netaddr/1","title":"NetAddr.netaddr/1","type":"function","doc":"Constructs a NetAddr.t/0 struct given a network address binary. Examples iex&gt; NetAddr.netaddr &lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt; %NetAddr.MAC_48{address: &lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;, length: 48} iex&gt; NetAddr.netaddr &lt;&lt;1, 2, 3, 4, 5&gt;&gt; %NetAddr.Generic{address: &lt;&lt;1, 2, 3, 4, 5&gt;&gt;, length: 40}"},{"ref":"NetAddr.html#netaddr/2","title":"NetAddr.netaddr/2","type":"function","doc":"Constructs a NetAddr.t/0 struct given a network address binary and an address length."},{"ref":"NetAddr.html#netaddr/3","title":"NetAddr.netaddr/3","type":"function","doc":"Explicitly constructs a NetAddr.Generic.t/0 struct. Examples iex&gt; NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;, 48, 6) %NetAddr.Generic{address: &lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;, length: 48} iex&gt; NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;, 48, 6) %NetAddr.Generic{address: &lt;&lt;0, 1, 2, 3, 4, 5&gt;&gt;, length: 48}"},{"ref":"NetAddr.html#netaddr_2/1","title":"NetAddr.netaddr_2/1","type":"function","doc":"Identical to netaddr/1, but returns {:ok, value} on success instead of just value. Examples iex&gt; NetAddr.netaddr_2(&lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;) {:ok, %NetAddr.MAC_48{address: &lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;, length: 48}} iex&gt; NetAddr.netaddr_2(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;) {:ok, %NetAddr.Generic{address: &lt;&lt;1, 2, 3, 4, 5&gt;&gt;, length: 40}}"},{"ref":"NetAddr.html#netaddr_2/2","title":"NetAddr.netaddr_2/2","type":"function","doc":"Identical to netaddr/2, but returns {:ok, value} on success instead of just value. Examples iex&gt; NetAddr.netaddr_2(&lt;&lt;1,2,3,4&gt;&gt;, 16) {:ok, %NetAddr.IPv4{address: &lt;&lt;1,2,3,4&gt;&gt;, length: 16}} iex&gt; NetAddr.netaddr_2(&lt;&lt;1,2,3,4&gt;&gt;, 33) {:error, :einval}"},{"ref":"NetAddr.html#netaddr_2/3","title":"NetAddr.netaddr_2/3","type":"function","doc":"Identical to netaddr/3, but returns {:ok, value} on success instead of just value. Examples iex&gt; NetAddr.netaddr_2(&lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;, 48, 6) {:ok, %NetAddr.Generic{address: &lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;, length: 48}} iex&gt; NetAddr.netaddr_2(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;, 48, 6) {:ok, %NetAddr.Generic{address: &lt;&lt;0, 1, 2, 3, 4, 5&gt;&gt;, length: 48}}"},{"ref":"NetAddr.html#netaddr_to_erl_ip/1","title":"NetAddr.netaddr_to_erl_ip/1","type":"function","doc":"Constructs an Erlang/OTP IP address tuple given a NetAddr.t/0. Examples iex&gt; NetAddr.netaddr_to_erl_ip NetAddr.ip(&quot;192.0.2.1&quot;) {192, 0, 2, 1} iex&gt; NetAddr.netaddr_to_erl_ip NetAddr.ip(&quot;2001:db8::1&quot;) {0x2001, 0xdb8, 0, 0, 0, 0, 0, 1}"},{"ref":"NetAddr.html#netaddr_to_list/1","title":"NetAddr.netaddr_to_list/1","type":"function","doc":"Converts a NetAddr.t/0 to a list of bytes. Examples iex&gt; NetAddr.ip(&quot;192.0.2.3/24&quot;) ...&gt; |&gt; NetAddr.netaddr_to_list [192, 0, 2, 3]"},{"ref":"NetAddr.html#netaddr_to_ptr/1","title":"NetAddr.netaddr_to_ptr/1","type":"function","doc":"Converts a NetAddr.t/0 to a format suitable for DNS PTR records. Examples iex&gt; NetAddr.netaddr_to_ptr NetAddr.ip(&quot;192.0.2.1&quot;) {:ok, &quot;1.2.0.192.in-addr.arpa&quot;} iex&gt; NetAddr.netaddr_to_ptr NetAddr.ip(&quot;2001:db8::1&quot;) {:ok, &quot;1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.8.b.d.0.1.0.0.2.ip6.arpa&quot;}"},{"ref":"NetAddr.html#netaddr_to_range/1","title":"NetAddr.netaddr_to_range/1","type":"function","doc":"Converts a NetAddr.t/0 to a t:Range.t/0. Examples iex&gt; NetAddr.netaddr_to_range NetAddr.ip(&quot;198.51.100.0/24&quot;) 3325256704..3325256959"},{"ref":"NetAddr.html#netaddr_to_regex/1","title":"NetAddr.netaddr_to_regex/1","type":"function","doc":"Convert IPv4 netaddr to a regular expression. Examples iex&gt; NetAddr.netaddr_to_regex NetAddr.ip(&quot;192.0.2.0/23&quot;) ~r/\\b192\\.0\\.[2-3]\\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\\b/ iex&gt; NetAddr.netaddr_to_regex NetAddr.ip(&quot;192.0.64.0/17&quot;) ~r/\\b192\\.0\\.([0-9]|[1-9][0-9]|1[0-1][0-9]|12[0-7])\\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\\b/"},{"ref":"NetAddr.html#netaddr_to_string/1","title":"NetAddr.netaddr_to_string/1","type":"function","doc":"Returns a human-readable CIDR or pseudo-CIDR for netaddr. This is like NetAddr.prefix/1 except host bits are not set to zero. All String.Chars implementations call this function. Examples iex&gt; NetAddr.netaddr_to_string %NetAddr.Generic{address: &lt;&lt;1, 2, 3, 4, 5&gt;&gt;, length: 32} &quot;0x0102030405/32&quot;"},{"ref":"NetAddr.html#network/1","title":"NetAddr.network/1","type":"function","doc":"Returns a human-readable string for the first address in netaddr. Examples iex&gt; NetAddr.network NetAddr.ip(&quot;192.0.2.1/24&quot;) &quot;192.0.2.0&quot;"},{"ref":"NetAddr.html#ntoa/2","title":"NetAddr.ntoa/2","type":"function","doc":"Converts decimal to an address. Examples iex&gt; NetAddr.ntoa 3221225985, 4 &lt;&lt;192, 0, 2, 1&gt;&gt; iex&gt; NetAddr.ntoa 338288524986991696549538495105230488577, 16 &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt; iex&gt; NetAddr.ntoa 4328719365, 5 &lt;&lt;1, 2, 3, 4, 5&gt;&gt;"},{"ref":"NetAddr.html#prefix/1","title":"NetAddr.prefix/1","type":"function","doc":"Returns a human-readable CIDR for the first address in netaddr. Examples iex&gt; NetAddr.prefix %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 24} &quot;192.0.2.0/24&quot; iex&gt; NetAddr.prefix %NetAddr.Generic{address: &lt;&lt;1, 2, 3, 4, 5&gt;&gt;, length: 32} &quot;0x0102030400/32&quot;"},{"ref":"NetAddr.html#ptr_to_netaddr/1","title":"NetAddr.ptr_to_netaddr/1","type":"function","doc":"Convert a DNS PTR record name to a NetAddr.t/0. Examples iex&gt; NetAddr.ptr_to_netaddr &quot;1.2.0.192.in-addr.arpa&quot; {:ok, %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 32}} iex&gt; NetAddr.ptr_to_netaddr &quot;1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.8.b.d.0.1.0.0.2.ip6.arpa&quot; {:ok, %NetAddr.IPv6{address: &lt;&lt;0x2001::2*8,0xdb8::2*8,0::11*8,1&gt;&gt;, length: 128}}"},{"ref":"NetAddr.html#range_to_netaddr/2","title":"NetAddr.range_to_netaddr/2","type":"function","doc":"Converts range to a NetAddr.t/0 given an address size hint. Examples iex&gt; NetAddr.range_to_netaddr 3325256704..3325256959, 4 %NetAddr.IPv4{address: &lt;&lt;198, 51, 100, 0&gt;&gt;, length: 24}"},{"ref":"NetAddr.html#sigil_p/2","title":"NetAddr.sigil_p/2","type":"macro","doc":"Succinctly describe IP NetAddrs at compile time. Examples iex&gt; use NetAddr iex&gt; ~p&quot;192.0.2.1/24&quot; %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 24} iex&gt; use NetAddr iex&gt; ~p&quot;2001:db8::1&quot; %NetAddr.IPv6{ address: &lt;&lt;0x2001::16,0xdb8::16,0::5*16,1::16&gt;&gt;, length: 128, } iex&gt; use NetAddr iex&gt; ~p(192.0.2.1/24 2001:db8::1) [ %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 24}, %NetAddr.IPv6{ address: &lt;&lt;0x2001::16,0xdb8::16,0::5*16,1::16&gt;&gt;, length: 128, }, ]"},{"ref":"NetAddr.html#subnet_mask/1","title":"NetAddr.subnet_mask/1","type":"function","doc":"Returns a human-readable address mask for ipv4_netaddr. Examples iex&gt; NetAddr.subnet_mask %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 24} &quot;255.255.255.0&quot;"},{"ref":"NetAddr.html#t:erl_ip/0","title":"NetAddr.erl_ip/0","type":"type","doc":""},{"ref":"NetAddr.html#t:ipv4_tuple/0","title":"NetAddr.ipv4_tuple/0","type":"type","doc":""},{"ref":"NetAddr.html#t:ipv6_tuple/0","title":"NetAddr.ipv6_tuple/0","type":"type","doc":""},{"ref":"NetAddr.html#t:sexdectet/0","title":"NetAddr.sexdectet/0","type":"type","doc":""},{"ref":"NetAddr.html#t:t/0","title":"NetAddr.t/0","type":"type","doc":""},{"ref":"NetAddr.Generic.html","title":"NetAddr.Generic","type":"module","doc":"Defines a struct to represent network addresses of arbitrary size."},{"ref":"NetAddr.Generic.html#t:t/0","title":"NetAddr.Generic.t/0","type":"type","doc":""},{"ref":"NetAddr.IPv4.html","title":"NetAddr.IPv4","type":"module","doc":"Defines a struct to represent IPv4 network addresses."},{"ref":"NetAddr.IPv4.html#t:t/0","title":"NetAddr.IPv4.t/0","type":"type","doc":""},{"ref":"NetAddr.IPv6.html","title":"NetAddr.IPv6","type":"module","doc":"Defines a struct to represent IPv6 network addresses."},{"ref":"NetAddr.IPv6.html#t:t/0","title":"NetAddr.IPv6.t/0","type":"type","doc":""},{"ref":"NetAddr.MAC_48.html","title":"NetAddr.MAC_48","type":"module","doc":"Defines a struct to represent MAC-48 network addresses."},{"ref":"NetAddr.MAC_48.html#t:t/0","title":"NetAddr.MAC_48.t/0","type":"type","doc":""},{"ref":"NetAddr.Representation.html","title":"NetAddr.Representation","type":"protocol","doc":""},{"ref":"NetAddr.Representation.html#address/2","title":"NetAddr.Representation.address/2","type":"function","doc":""},{"ref":"NetAddr.Representation.html#t:t/0","title":"NetAddr.Representation.t/0","type":"type","doc":""},{"ref":"NetAddr.Utility.html","title":"NetAddr.Utility","type":"module","doc":"Every project needs a junk drawer."},{"ref":"NetAddr.Utility.html#range_to_regex/1","title":"NetAddr.Utility.range_to_regex/1","type":"function","doc":""},{"ref":"NetAddr.Utility.html#t:range/0","title":"NetAddr.Utility.range/0","type":"type","doc":""},{"ref":"NetAddr.Utility.html#t:regex/0","title":"NetAddr.Utility.regex/0","type":"type","doc":""},{"ref":"readme.html","title":"netaddr-elixir","type":"extras","doc":"netaddr-elixir General functions for network address parsing and manipulation, with support for addresses of arbitrary size. See the API documentation. Parsing: iex&gt; use NetAddr NetAddr iex&gt; ~p(192.0.2.1 198.51.100.0/24 ::/0) [ %NetAddr.IPv4{address: &lt;&lt;192,0,2,1&gt;&gt;, length: 32}, %NetAddr.IPv4{address: &lt;&lt;198,51,100,0&gt;&gt;, length: 24}, %NetAddr.IPv6{address: &lt;&lt;0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0&gt;&gt;, length: 0} ] iex&gt; NetAddr.ip &quot;192.0.2.1/24&quot; %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 24} iex&gt; NetAddr.ip &quot;192.0.2.1&quot; %NetAddr.IPv4{address: &lt;&lt;192, 0, 2, 1&gt;&gt;, length: 32} iex&gt; NetAddr.ip &quot;fe80:0:c100::c401/64&quot; %NetAddr.IPv6{address: &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt;, length: 64} iex&gt; NetAddr.ip &quot;fe80:0:c100::c401&quot; %NetAddr.IPv6{address: &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt;, length: 128} Pretty-printing: iex&gt; &quot;\#{NetAddr.ip(&quot;192.0.2.1/24&quot;)}&quot; &quot;192.0.2.1/24&quot; iex&gt; &quot;\#{NetAddr.ip(&quot;fe80:0:c100::c401&quot;)}&quot; &quot;fe80:0:c100::c401/128&quot; Conversion: iex&gt; NetAddr.network NetAddr.ipv4_cidr(&quot;192.0.2.1/24&quot;) &quot;192.0.2.0&quot; iex&gt; NetAddr.ip(&quot;192.0.2.1/24&quot;) |&gt; NetAddr.address_length(22) |&gt; NetAddr.network &quot;192.0.0.0&quot; iex&gt; NetAddr.aton &lt;&lt;192,0,2,1&gt;&gt; 3221225985 iex&gt; NetAddr.ntoa 3221225985, 4 &lt;&lt;192, 0, 2, 1&gt;&gt; iex&gt; NetAddr.aton &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt; 338288524986991696549538495105230488577 iex&gt; NetAddr.ntoa 338288524986991696549538495105230488577, 16 &lt;&lt;254, 128, 0, 0, 193, 0, 0, 0, 0, 0, 0, 0, 0, 0, 196, 1&gt;&gt; iex&gt; NetAddr.length_to_mask(30, 4) &lt;&lt;255, 255, 255, 252&gt;&gt; iex&gt; NetAddr.length_to_mask(64, 16) &lt;&lt;255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0&gt;&gt; iex&gt; NetAddr.ip(&quot;198.51.100.0/24&quot;) |&gt; NetAddr.netaddr_to_range 3325256704..3325256959 iex&gt; NetAddr.range_to_netaddr 3325256704..3325256959, 4 %NetAddr.IPv4{address: &lt;&lt;198, 51, 100, 0&gt;&gt;, length: 24} Arbitrary length addresses: iex&gt; NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;) %NetAddr.MAC_48{address: &lt;&lt;1, 2, 3, 4, 5, 6&gt;&gt;, length: 48} iex&gt; NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;, 48, 6) %NetAddr.Generic{address: &lt;&lt;0, 1, 2, 3, 4, 5&gt;&gt;, length: 48} iex&gt; NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;) %NetAddr.Generic{address: &lt;&lt;1, 2, 3, 4, 5&gt;&gt;, length: 40} iex&gt; &quot;\#{NetAddr.netaddr(&lt;&lt;1, 2, 3, 4, 5&gt;&gt;)}&quot; &quot;0x0102030405/40&quot; iex&gt; NetAddr.aton(&lt;&lt;1,2,3,4,5&gt;&gt;) 4328719365 iex&gt; NetAddr.ntoa 4328719365, 5 &lt;&lt;1, 2, 3, 4, 5&gt;&gt; iex&gt; NetAddr.length_to_mask(37, 6) &lt;&lt;255, 255, 255, 255, 248, 0&gt;&gt;"}]